@@ -11,7 +11,7 @@ from pandas import DataFrame
 from pandas.testing import assert_series_equal
 
 from timeseriesflattener import TimeseriesFlattener
-from timeseriesflattener.feature_spec_objects import AnySpec
+from timeseriesflattener.feature_spec_objects import _AnySpec
 from timeseriesflattener.testing.load_synth_data import (
     load_synth_outcome,
     load_synth_prediction_times,
@@ -78,7 +78,7 @@ def str_to_df(
 
 def assert_flattened_data_as_expected(
     prediction_times_df: Union[pd.DataFrame, str],
-    output_spec: AnySpec,
+    output_spec: _AnySpec,
     expected_df: Optional[pd.DataFrame] = None,
     expected_values: Optional[Sequence[Any]] = None,
 ):
@@ -117,10 +117,27 @@ def assert_flattened_data_as_expected(
         raise ValueError("Must provide an expected set of data")
 
 
+def load_long_df_with_multiple_values():
+    """Create a long df."""
+    df = synth_predictor_binary()
+    df = df.rename(columns={"value": "value_name_1"})
+    df["value_name_2"] = df["value_name_1"]
+
+    long_df = pd.melt(
+        df,
+        id_vars=["entity_id", "timestamp"],
+        value_vars=["value_name_1", "value_name_2"],
+        var_name="value_names",
+        value_name="value",
+    )
+
+    return long_df
+
+
 @data_loaders.register("load_event_times")
 def load_event_times():
     """Load event times."""
-    event_times_str = """id,timestamp,value,
+    event_times_str = """entity_id,timestamp,value,
                     1,2021-12-30 00:00:01, 1
                     1,2021-12-29 00:00:02, 2
                     """
@@ -160,18 +177,6 @@ def synth_outcome():
 
 
 @pytest.fixture(scope="function")
-def long_df():
-    """Create a long df."""
-    synth_df = synth_predictor_binary()
-    synth_df = synth_df.rename(columns={"value": "value_name_1"})
-    synth_df["value_name_2"] = synth_df["value_name_1"]
-
-    df = pd.melt(
-        synth_df,
-        id_vars=["id", "timestamp"],
-        value_vars=["value_name_1", "value_name_2"],
-        var_name="value_names",
-        value_name="value",
-    )
-
-    return df
+def long_df_with_multiple_values():
+    """Load the long df."""
+    return load_long_df_with_multiple_values()
